orderMenu = {}
local orderMenu_mt = Class(orderMenu)

orderMenu.buildId = 1
orderMenu.versionString = "1.0.0.0"

function orderMenu:new(isServer, isClient, customEnvironment, baseDirectory)
    if g_orderMenu ~= nil then
        return
    end

    local self = {}
    setmetatable(self, orderMenu_mt)

    self.isServer = isServer
    self.isClient = isClient

    local globalTexts = getfenv(0).g_i18n.texts
    for k, v in pairs (g_i18n.texts) do
        local prefix, _ = k:find("OM_", 1, true)
        if prefix ~= nil then
            globalTexts[k] = v
        end
    end

    self.isEnabled = false
    self.printToLog = false

    self.customEnvironment = customEnvironment
    self.baseDirectory = baseDirectory

    self.deleteInputActive = false

    addModEventListener(self)

    return self
end

function orderMenu:load(isReload)

    if self.isClient then
        g_gui:loadProfiles(self.baseDirectory .. "gui/guiProfiles.xml")

        local tabbedMenu = orderMenuTabbedMenu:new(nil, g_messageCenter, g_i18n, g_gui.inputManager, self.printToLog)

        local generalFrame = orderMenuGeneralFrame:new()

        g_gui:loadGui(self.baseDirectory .. "gui/orderMenuGeneralFrame.xml", "orderMenuGeneralFrame", generalFrame, true)
        g_gui:loadGui(self.baseDirectory .. "gui/orderMenuTabbedMenu.xml", "orderMenuTabbedMenu", tabbedMenu)

        self.isEnabled = true
    end
end

function orderMenu:deleteMap()
    self.deleteInputActive = false

    if self.guiCreator ~= nil then
        self.guiCreator:delete()
    end

    getfenv(0)["g_orderMenu"] = nil
end

function orderMenu:draw()
    if g_dedicatedServerInfo ~= nil or g_currentMission.player == nil or g_currentMission.controlledVehicle ~= nil then
        return
    end
end

function orderMenu:onInputOpenMenu(_, inputValue)
    if self.isEnabled and not g_gui:getIsGuiVisible() then
        self.easyDevGui = g_gui:showGui("orderMenuTabbedMenu")
    end
end

function orderMenuInit(name, c)
    if name == nil or c == nil then
        return
    end

    if g_orderMenu == nil then
        if (name == "FS19_orderMenu" or name == "FS19_orderMenu_update") and c:len() == 15 then
            local modDir = g_currentModDirectory
            local orderMenu = orderMenu:new(g_server ~= nil, g_dedicatedServerInfo == nil, name, modDir)
            if orderMenu ~= nil then
                getfenv(0)["g_orderMenu"] = orderMenu

                source(modDir .. "scripts/gui/orderMenuTabbedMenu.lua")
                source(modDir .. "scripts/gui/orderMenuGeneralFrame.lua")
				source(modDir .. "scripts/events/orderMenuSiloCheatEvent.lua")

                FSBaseMission.loadMapFinished = Utils.prependedFunction(FSBaseMission.loadMapFinished, loadMapFinished)
				FSBaseMission.onConnectionFinishedLoading = Utils.appendedFunction(FSBaseMission.onConnectionFinishedLoading, onConnectionFinishedLoading)

                FSBaseMission.registerActionEvents = Utils.appendedFunction(FSBaseMission.registerActionEvents, registerActionEvents)
                BaseMission.unregisterActionEvents = Utils.appendedFunction(BaseMission.unregisterActionEvents, unregisterActionEvents)

                print("  Loaded HoT order menu")
            end
        else
            getfenv(0)["g_orderMenuError"] = {c = c, name = name, startUpdateTime = 2000}

            g_orderMenuError.update = function(g_orderMenuError, dt)
                if g_orderMenuError ~= nil then
                    if g_orderMenuError.startUpdateTime > 0 then
                        g_orderMenuError.startUpdateTime = g_orderMenuError.startUpdateTime - dt
                    else
                    end
                end
            end

            g_orderMenuError.openModHubLink = function(isYes)
                removeModEventListener(g_orderMenuError)
                getfenv(0)["g_orderMenuError"] = nil
            end

            g_orderMenuError.delete = function()
                if g_orderMenuError ~= nil then
                    removeModEventListener(g_orderMenuError)
                    getfenv(0)["g_orderMenuError"] = nil
                end
            end

            addModEventListener(g_orderMenuError)
        end
    end
end

function loadMapFinished()
    if g_orderMenu ~= nil then
        g_orderMenu:load(false)
    end
end

function onConnectionFinishedLoading(mission, connection, x, y, z, viewDistanceCoeff)
    if g_orderMenu ~= nil then
        g_orderMenu:onConnectionFinishedLoading(connection)
    end
end

function orderMenu:onConnectionFinishedLoading(connection)
    if g_currentMission.player == nil then
		return
	end
end



function registerActionEvents()
    if g_dedicatedServerInfo == nil and g_orderMenu ~= nil then
        local _, eventId = g_inputBinding:registerActionEvent(InputAction.OM_openMenu, g_orderMenu, g_orderMenu.onInputOpenMenu, false, true, false, true)
        g_inputBinding:setActionEventTextVisibility(eventId, false)
        g_orderMenu.eventIdOpenMenu = eventId
    end
end

function unregisterActionEvents()
    if g_orderMenu ~= nil then
        g_inputBinding:removeActionEventsByTarget(g_orderMenu)
    end
end



orderMenuInit(g_currentModName, g_modManager:getModByName(g_currentModName).author)
